@@ -111,5 +111,21 @@ jazz = [
 jazz2 = [
 	ChromaticSoloist({'channel': 0, 'midi_instr': randrange(20,100)}),
 	FastStridePianist({'channel': 5, 'start':0}),
+	]
 
+jazz_quartet = [
+	JazzDrum({}),
+	WalkingBass({'channel': 8}),
+	ChordInstrument({'channel': 10, 'midi_instr': 1}),
+	SoloInstrument({'channel': 11, 'midi_instr': 2, 'max_velocity':70, 'step': 1, 'start': 1, 'chance': 0.7}),
+	SoloInstrument({'channel':12, 'midi_instr': 66, 'start': 0, 'step': 1, 'chance': 0.7}),
+	]
+
+jazz_battle = [
+	JazzDrum({}),
+	WalkingBass({'channel': 8, 'start': 0}),
+	ChordInstrument({'channel': 10, 'midi_instr': 1}),
+	SoloInstrument({'channel': 11, 'midi_instr': 2, 'max_velocity':70, 'step': 1, 'start': 1, 'chance': 0.7}),
+	SoloInstrument({'channel':12, 'midi_instr': 66, 'start': 0, 'step': 1, 'chance': 0.7}),
+	SoloInstrument({'channel':13, 'midi_instr': 11, 'start': 8, 'step': 4, 'chance': 0.7}),
 	]
