@@ -6,14 +6,14 @@ class Block:
 
 	progressions = Contemporary.reincarnatie
 	
-	bpm = 200
+	bpm = 120
 	resolution = 8
 	meter = (4,4)
 	duration = 2
 
 	swing = True
 	key = 'A'
-	instruments = Bands.dummy
+	instruments = []
 
 	wildness = 0.5
 
