@@ -1,5 +1,6 @@
 from RockDrum import RockDrum
 from JazzDrum import JazzDrum
 from BlastBeat import BlastBeat
+from Metronome import Metronome
 
-__all__ = ['RockDrum', 'JazzDrum', 'BlastBeat']
+__all__ = ['RockDrum', 'JazzDrum', 'BlastBeat', 'Metronome']
